Exception: Emailvision::SessionError

Inherits:
Exception
  • Object
show all
Defined in:
lib/emailvision/session_error.rb

Overview

Session Error

This error is raised when the token has expired or the number of connections has been reached